%% Animate the plots
% ODE45 is a variable time step Ordinary Differential Equation solver.
% This means that the time step changes. This makes the solver much more
% efficient since it can use large time steps when the dynanmic equations
% of motion are relatively easy to solve.  However, to animate the plots,
% we want to nice, even timing.  Thus, we are are going to make splines of
% each variable 

function Animate_Trebuchet(Yout, time)
load TrebuchetDataFile.mat
theta      = Yout(:,1);           %angular position of main arm
thetaDot   = Yout(:,2);           %angular velocity of main arm
thetaDDot  = [0; diff(thetaDot)]; %angular acceleration of main arm
phi        = Yout(:,3);           %angular position of swing arm
phiDot     = Yout(:,4);           %angular velocity of swing arm
phiDDot    = [0; diff(phiDot)];   %angular acceleration of swing arm
gamma      = Yout(:,5);           %angular position of rope
gammaDot   = Yout(:,6);           %angular velocity of rope
gammaDDot  = [0; diff(gammaDot)]; %angular acceleration of rope 

dt = 0.01;
thetaSpline = spline(time, theta, 0:dt:time(length(time)));
phiSpline = spline(time, phi, 0:dt:time(length(time)));
gammaSpline = spline(time, gamma, 0:dt:time(length(time)));
figure(7); clf
fill([-pivot_height/3 0 pivot_height/3], [-pivot_height 0 -pivot_height],'b')
axis([-3*pivot_height pivot_height -pivot_height 2*pivot_height])
xlabel('X (m)')
ylabel('Y (m)')
for i = 1:length(thetaSpline)
    figure(7)
    L1 = line([-L*cos(thetaSpline(i)) l*cos(thetaSpline(i))],...
        [-L*sin(thetaSpline(i)) l*sin(thetaSpline(i))]);
    L3 = line([l*cos(thetaSpline(i)), l*cos(thetaSpline(i)) + r*sin(phiSpline(i))],...
        [l*sin(thetaSpline(i)), l*sin(thetaSpline(i)) - r*cos(phiSpline(i)) ]);
    L4 = line([-L*cos(thetaSpline(i)), -L*cos(thetaSpline(i)) + n*sin(gammaSpline(i))],...
        [-L*sin(thetaSpline(i)), -L*sin(thetaSpline(i)) - n*cos(gammaSpline(i)) ]);
    set(L1, 'color', 'r', 'linewidth', 2);
    set(L3, 'color', 'k', 'linewidth', 2);
    set(L4, 'color', 'g', 'linewidth', 2);
    M4(i) = getframe;
%     pause
end