function ReactionForce = Calculate_Reaction_Force(Yout)
load TrebuchetDataFile.mat
theta      = Yout(:,1);           %angular position of main arm
thetaDot   = Yout(:,2);           %angular velocity of main arm
thetaDDot  = [0; diff(thetaDot)]; %angular acceleration of main arm
phi        = Yout(:,3);           %angular position of swing arm
phiDot     = Yout(:,4);           %angular velocity of swing arm
phiDDot    = [0; diff(phiDot)];   %angular acceleration of swing arm
gamma      = Yout(:,5);           %angular position of rope
gammaDot   = Yout(:,6);           %angular velocity of rope
gammaDDot  = [0; diff(gammaDot)]; %angular acceleration of rope


% you must ensure that this value is less than what your joint can handle!
Rx = []; %preallocate the reaction force in the X direction
Ry = []; %preallocate the reaction force in the Y direction
for index=1:length(theta)
    if -L*sin(theta(index))-n*cos(gamma(index)) <= -pivot_height
        Rx(index) =  M*g*sin(theta(index)) + M*(l*theta(index)^2   ...
            - phiDDot(index)*r*cos(theta(index)-phi(index)) - ...
            phiDot(index)*r*sin(theta(index)-phi(index)));
        Ry(index) =  M*g*cos(theta(index)) - M*(l*thetaDDot(index) + ...
            phiDDot(index)*r*sin(theta(index)-phi(index)) - ...
            phiDot(index)*r*sin(theta(index)-phi(index)));
    else
        Rx(index) = m*(-L*thetaDot(index)^2  - ...
            gammaDDot(index)*n*cos(theta(index)-gamma(index)) - ...
            gammaDot(index)*n*sin(theta(index)-gamma(index))) + ...
            m*g*sin(theta(index)) + M*g*sin(theta(index)) + ...
            M*(l*theta(index)^2   - ...
            phiDDot(index)*r*cos(theta(index)-phi(index)) - ...
            phiDot(index)*r*sin(theta(index)-phi(index)));
        Ry(index) = m*(L*thetaDDot(index)    + ...
            gammaDDot(index)*n*sin(theta(index)-gamma(index)) - ...
            gammaDot(index)*n*sin(theta(index)-gamma(index))) + ...
            m*g*cos(theta(index)) + M*g*cos(theta(index)) - ...
            M*(l*thetaDDot(index) + ...
            phiDDot(index)*r*sin(theta(index)-phi(index)) - ...
            phiDot(index)*r*sin(theta(index)-phi(index)));
    end
end
ReactionForce = sqrt(Rx.^2 + Ry.^2);