function output = Trebuchet4(~,INPUT)
% assumptions
% pumpkin is point mass
% counterweight is point mass
% beam is massless
% counterweight swings at end of weight
% pumpkin is attached to end by rope

%load the constant parameters
load TrebuchetDataFile.mat

theta = INPUT(1);
thetaDot = INPUT(2);
phi = INPUT(3);
phiDot = INPUT(4);
gamma = INPUT(5);
gammaDot = INPUT(6);


if -L*sin(theta)-n*cos(gamma) <= -pivot_height
    Ftheta = -m*g*L*cos(theta)+m*g*n*sin(gamma);
    Fgamma = m*g*n*sin(gamma);
else
    Ftheta = 0;
    Fgamma = 0;
end

% Solve for the right-hand-side of the equation.
% Make sure this is in vector form
rhs(1) =                                               m*L*n*gammaDot^2*cos(gamma-theta) - M*l*r*phiDot^2  *cos(phi-theta) + (m*L-M*l)*g*cos(theta) + Ftheta;
rhs(2) =                                                                                   M*l*r*thetaDot^2*cos(phi-theta) -       M*r*g*sin(phi);
rhs(3) = -2*m*L*n*thetaDot*gammaDot*cos(gamma-theta) + m*L*n*thetaDot^2*cos(gamma-theta)                                   -       m*n*g*sin(gamma) + Fgamma;

% Input the left hand side coefficients for acceleration.  Make sure this
% is in matrix form
C(1,1) = m*L^2 + M*l^2;
C(1,2) = M*l*r*sin(phi-theta);
C(1,3) = -m*L*n*sin(gamma-theta);
C(2,1) = M*l*r*sin(phi-theta);
C(2,2) = M*r^2;
C(2,3) = 0;
C(3,1) = -m*L*n*sin(gamma-theta);
C(3,2) = 0;
C(3,3) = m*n^2;
%Solve for the angular acceleration
AngularAcceleration = C \ rhs';

%Extract the individual acclerations from the Angular Acceleration vector.
thetaDDot = AngularAcceleration(1);
phiDDot = AngularAcceleration(2);
gammaDDot = AngularAcceleration(3);
%output the desired variable
output = [thetaDot; thetaDDot; phiDot; phiDDot; gammaDot; gammaDDot];
