%% 2014 Matthew Spenko
% This program will simulate the dynamics of a simple trebuchet with a main
% arm, a swing arm, and a rope that connects the main arm to the projectile
% I posted a diagram on the mechanicaldesign.iit.edu website to illustrate
% the links and angles.

clear                       %clear all variables
clc                         %clear the matlab screen
close all                   %close all open figures
%% assign the constants
m               = 0.036;    %mass of water filled ping pong ball(kg)
M               = 2;        %mass of counterweight (kg)
g               = 9.8;      %gravity (m/s^2)
%% assign the variables - You must change these variables to suit your particular design.
% A hint: keep pivot_height less than 0.55 to make fabrication easy on the 
% laser cutter
L               = 0.37;      %distance from pivot point to projectile (m)
l               = 0.19;      %length from pivot to hinge (m)
r               = 0.08;      %length of counterweight pivot (m)
n               = 0.3;      %length of rope attaching pumpkin to arm (m)
pivot_height    = 0.5;      %distance from the ground to the pivot point,
lr              = l + r;    %length fron pivot to counter weight
h               = 0.02;         %height of beam (m)
w               = 1/4*.0254;    %width of beam (m), assumes 1/4" mdf
%% Estimate the link inertias
% To properly estimate the distance, we need to calculate the inertia of
% the beams.  This is an estimate only, and you are free to override it
% if you like with more exact measurements.
density         = 750;              %density of MDF (kg/m^3)
mL              = L*h*w*density;    %mass of L arm (kg)
ml              = l*h*w*density;    %mass of l arm (kg)

%% Set up the initial conditions for the angles
% set the pivot height to be something reasonable.  Theoretically you
% should be able to set it to anything < 90 deg.  However, I found this
% impractical.  For simulation purposes, your maximum should be about
% 80 deg.  If you start to get tolerance errors when running your
% simulation, reduce this value.
% If L is greater thang the pivot height, then the maximum theta may be
% limited.  I use the geometry of the trebuchet to determine this value
thetainitial = setthetainitial(L, pivot_height);
phiinitial = [0*pi/180; 0];
%calculate the angle between newtonian vertical and rope vertical (radians)
gammainitial = [acos((pivot_height-L*sin(thetainitial(1)))/n); 0];
%% Check to ensure that the configuration you chose is physically realizable
% check to ensure that the pivot height is less than L+n so the projectile
% starts on the ground.  This ensures the simulation will work.  It also
% seems to be what people do in practice.
check_pivot_height(L, n, lr, pivot_height)
%% End the initialization
%save the parameters so that the function files can use them.  The function
%files refer to the dynamic equations of motion that you are simulating.  I
%have done the hard work for you in calculating the equations of motion.
%You will learn more about how to calculate equations of motion in MMAE
%305: Dynamics.
save TrebuchetDataFile.mat
%Set the time span to simulate the dynamical system (s)
tspan = [0 2];

%% Simulate the dynamic equations of motion of the system using ode45
%[time out, variable out] = ODE45(function, time_span, initial_conditions)
options = odeset('Events',@trebuchetevents,'Refine',4);
[time, Yout, TE, YE, IE] = ode45(@Trebuchet4, tspan, [thetainitial; phiinitial; gammainitial], options);

%% Use the output data to get some interesting plots and values.
%%Calculate the reaction force on the main pin.
ReactionForce = Calculate_Reaction_Force(Yout);
projectile_dist = Calculate_Launch_Distance(Yout);
%% Find the launch window that ensures the projectile will travel at least X m
launchwindow = Calculate_Launch_Window(projectile_dist, 15, time);

%% Plot the reaction force at the main arm pivot point.
figure(1); clf; hold on
plot(time, ReactionForce, 'linewidth', 2)
xlabel('Time (s)')
ylabel('Reachtion Force on pivot (N)')
grid on

%% Plot the launch distance as a function of when the projectile is released
figure(2); clf; hold on
plot(time, projectile_dist, 'linewidth', 2)
xlabel('Time (s)')
ylabel('Distance Travelled if launched at this time (m)')
grid on

%animate the Trebuchet
Animate_Trebuchet(Yout, time)




